@@ -303,11 +303,24 @@ def copy_attribute(desobj, name, srcobj, ctx):
     except AttributeError:
         pass  # auto convert to numpy array
     # First, make sure we have a NumPy array.
-    srcarr = np.asarray(data, order='C', dtype=src_dt)
-    tgtarr = copy_array(srcarr, ctx)
+    if is_h5py(srcobj):
+        src_empty = h5py.Empty
+    else:
+        src_empty = h5pyd.Empty
+    if is_h5py(desobj):
+        des_empty = h5py.Empty
+    else:
+        des_empty = h5pyd.Empty
+    
+    if isinstance(data, src_empty):
+        # create Empty object with tgt dtype
+        tgt_dt = convert_dtype(src_dt, ctx)
+        tgtarr = des_empty(tgt_dt)
+    else:
+        srcarr = np.asarray(data, order='C', dtype=src_dt)
+        tgtarr = copy_array(srcarr, ctx)
     try:
         desobj.attrs.create(name, tgtarr)
-
     except (IOError, TypeError) as e:
         msg = "ERROR: failed to create attribute {} of object {} -- {}".format(name, desobj.name, str(e))
         logging.error(msg)
@@ -328,7 +341,7 @@ def create_dataset(dobj, ctx):
     chunks = None
     dset = None
 
-    if ctx["dataload"] == "link" and not is_vlen(dobj.dtype) and not is_compact(dobj):
+    if ctx["dataload"] == "link" and not is_vlen(dobj.dtype) and dobj.shape is not None and not is_compact(dobj):
         dset_dims = dobj.shape
         logging.debug("dset_dims: {}".format(dset_dims))
         rank = len(dset_dims)
@@ -340,6 +353,8 @@ def create_dataset(dobj, ctx):
         if chunk_dims:
             num_chunks = dsetid.get_num_chunks(spaceid)
 
+        logging.debug("num_chunks: {}".format(num_chunks))
+
         chunks = {}  # pass a map to create_dataset
 
         if num_chunks == 0:
@@ -415,7 +430,7 @@ def create_dataset(dobj, ctx):
 
     try:
         tgt_dtype = convert_dtype(dobj.dtype, ctx)
-        if len(dobj.shape) == 0 or (is_vlen(dobj.dtype) and is_h5py(fout)):
+        if dobj.shape is None or len(dobj.shape) == 0 or (is_vlen(dobj.dtype) and is_h5py(fout)):
             # don't use compression/chunks for scalar datasets
             # or vlen
             compression = None
@@ -445,6 +460,7 @@ def create_dataset(dobj, ctx):
             fletcher32=fletcher32, compression_opts=compression_opts,
             fillvalue=fillvalue, scaleoffset=scaleoffset)
         msg = "dataset created, uuid: {}, chunk_size: {}".format(dset.id.id, str(dset.chunks))
+        msg += " chunks: {}".format(chunks)
         logging.info(msg)
         if ctx["verbose"]:
             print(msg)
@@ -620,7 +636,7 @@ def create_datatype(obj, ctx):
 # create_datatype
 
 #----------------------------------------------------------------------------------
-def load_file(fin, fout, verbose=False, dataload="ingest", s3path=None, compression=None,compression_opts=None):
+def load_file(fin, fout, verbose=False, dataload="ingest", s3path=None, compression=None, compression_opts=None):
     logging.info("input file: {}".format(fin.filename))
     logging.info("output file: {}".format(fout.filename))
     if dataload != "ingest":
@@ -678,7 +694,7 @@ def load_file(fin, fout, verbose=False, dataload="ingest", s3path=None, compress
         logging.debug("object_copy_helper for object: {}".format(obj.name))
 
         if class_name in ("Dataset", "Table"):
-            if ctx["dataload"] == "link" and not is_vlen(obj.dtype) and not is_compact(obj):
+            if ctx["dataload"] == "link" and not is_vlen(obj.dtype) and not is_compact(obj) and len(obj.shape) > 0:
                 logging.info("skip datacopy for link reference")
             else:
                 logging.debug("calling write_dataset for dataset: {}".format(obj.name))
