@@ -16,8 +16,9 @@ import os.path as op
 import numpy
 import collections
 
-from .base import HLObject, MutableMappingHDF5, guess_dtype
+from .base import HLObject, MutableMappingHDF5, guess_dtype, Empty
 from .objectid import TypeID, GroupID, DatasetID
+from .h5type import special_dtype
 from . import dataset
 from .dataset import Dataset
 from . import table
@@ -43,7 +44,6 @@ class Group(HLObject, MutableMappingHDF5):
         self._req_prefix = "/groups/" + self.id.uuid
         self._link_db = {}  # cache for links
 
-
     def _get_link_json(self, h5path):
         """ Return parent_uuid and json description of link for given path """
         self.log.debug("__get_link_json({})".format(h5path))
@@ -56,13 +56,12 @@ class Group(HLObject, MutableMappingHDF5):
         else:
             in_group = False  # may belong to some other group
 
-
         if h5path[0] == '/':
             #abs path, start with root
             # get root_uuid
             parent_uuid = self.id.http_conn.root_uuid
             # make a fake tgt_json to represent 'link' to root group
-            tgt_json = {'collection': "groups", 'class': "H5L_TYPE_HARD", 'id': parent_uuid }
+            tgt_json = {'collection': "groups", 'class': "H5L_TYPE_HARD", 'id': parent_uuid}
             if h5path == '/':
                 # asking for the root, just return the root link
                 return parent_uuid, tgt_json
@@ -74,7 +73,6 @@ class Group(HLObject, MutableMappingHDF5):
 
                 return parent_uuid, tgt_json
 
-
         path = h5path.split('/')
 
         objdb = self.id._http_conn.getObjDb()
@@ -122,8 +120,7 @@ class Group(HLObject, MutableMappingHDF5):
 
                 return group_uuid, tgt_json
             else:
-                 raise KeyError("Unable to open object (Component not found)")
-
+                raise KeyError("Unable to open object (Component not found)")
 
         for name in path:
             if not name:
@@ -305,29 +302,34 @@ class Group(HLObject, MutableMappingHDF5):
         if self.id.http_conn.mode == 'r':
             raise ValueError("Unable to create dataset (No write intent on file)")
 
-        if shape is None and data is None:
-            raise TypeError("Either data or shape must be specified")
-
         # Convert data to a C-contiguous ndarray
         if data is not None:
-            if dtype is None:
-                dtype = guess_dtype(data)
-            # if dtype is None:
-            #     dtype = numpy.float32
-            if not isinstance(data, numpy.ndarray) or dtype != data.dtype:
-                data = numpy.asarray(data, order="C", dtype=dtype)
-                dtype = data.dtype
-            self.log.info("data dtype: {}".format(data.dtype))
+            if isinstance(data, Empty):
+                if dtype is None:
+                    dtype = data.dtype
+            else:    
+                if dtype is None:
+                    dtype = guess_dtype(data)
+                if not isinstance(data, numpy.ndarray) or dtype != data.dtype:
+                    data = numpy.asarray(data, order="C", dtype=dtype)
+                    dtype = data.dtype
+                self.log.info("data dtype: {}".format(data.dtype))
 
         # Validate shape
-        if shape is None:
-            if data is None:
-                raise TypeError("Either data or shape must be specified")
-            shape = data.shape
+        if isinstance(data, Empty):
+            if shape:
+                raise ValueError("Shape tuple is incompatible with Empty object")
         else:
-            shape = tuple(shape)
-        if data is not None and (numpy.product(shape) != numpy.product(data.shape)):
-            raise ValueError("Shape tuple is incompatible with data")
+            if shape is None:
+                if  data is None:
+                    pass # null space dataset
+                else:
+                    shape = data.shape
+            else:
+                shape = tuple(shape)
+            
+            if data is not None and not isinstance(data, Empty) and (numpy.product(shape) != numpy.product(data.shape)):
+                raise ValueError("Shape tuple is incompatible with data")
 
         dsid = dataset.make_new_dset(self, shape=shape, dtype=dtype, **kwds)
         dset = dataset.Dataset(dsid)
@@ -791,7 +793,16 @@ class Group(HLObject, MutableMappingHDF5):
             #htype.commit(self.id, name, lcpl=lcpl)
 
         else:
-            pass #todo
+            if isinstance(obj, numpy.ndarray):
+                arr = obj
+            elif isinstance(obj, str):
+                dt = special_dtype(vlen=str)
+                arr = numpy.array(obj, dtype=dt)
+            else:
+                dt = guess_dtype(obj)
+                arr = numpy.array(obj, dtype=dt)
+            self.create_dataset(name, shape=arr.shape, dtype=arr.dtype, data=arr[...])
+        
             #ds = self.create_dataset(None, data=obj, dtype=base.guess_dtype(obj))
             #h5o.link(ds.id, self.id, name, lcpl=lcpl)
 
